package Bundle::Locale::CLDR::Micronesianregion;

use version;

our $VERSION = version->declare('v0.44.1');

=head1 NAME

Bundle::Locale::CLDR::Micronesianregion

=head1 CONTENTS

Locale::CLDR::Locales::En::Latn::Fm 0.44.1

Locale::CLDR::Locales::En::Latn::Gu 0.44.1

Locale::CLDR::Locales::En::Latn::Ki 0.44.1

Locale::CLDR::Locales::En::Latn::Mh 0.44.1

Locale::CLDR::Locales::En::Latn::Mp 0.44.1

Locale::CLDR::Locales::En::Latn::Nr 0.44.1

Locale::CLDR::Locales::En::Latn::Pw 0.44.1

Locale::CLDR::Locales::En::Latn::Um 0.44.1

Locale::CLDR::Locales::En::Latn::001 0.44.1


=cut

1;

